@@ -5,7 +5,10 @@ import tempfile
 import subprocess
 from io import BytesIO
 from trell.utils import logger
-
+import pathlib
+import traceback
+from trell import config
+bucket_obj: boto3.s3.transfer.S3Transfer = boto3.Session().resource('s3').Bucket(config.BUCKET_NAME)
 
 class S3:
 
@@ -98,3 +101,27 @@ class S3:
                     break
         except Exception as e:
             print(e)
+
+    @staticmethod
+    def download_file(s3_path="", remote_file_name="", local_dir_path=""):
+        """
+
+        :param str remote_file_name:
+        :param int partition:
+        :param int offset:
+        :param KafkaConsumer consumer:
+        :return:
+        """
+        try:
+            dir_path = pathlib.Path(local_dir_path)
+            dir_path.mkdir(parents=True, exist_ok=True)
+            path = dir_path.joinpath(remote_file_name)
+            dpath = str(dir_path.absolute())
+            fpath = str(path.absolute())
+            bucket_obj.download_file(s3_path, fpath)
+            return dpath, fpath
+
+
+        except Exception as err:
+            print("download failed, file name {} and error: {} ".format(remote_file_name, str(err)))
+            print(traceback.print_exc())
